@@ -3,6 +3,8 @@
 #include <iostream>
 using namespace std;
 
+QString baseDir();
+
 MainWindow::MainWindow(QObject *parent /*= 0*/)
 : QObject(parent)
 , gvApi (false, this)
@@ -11,8 +13,6 @@ MainWindow::MainWindow(QObject *parent /*= 0*/)
 , oInbox (gvApi, this)
 , checkCounter (0)
 {
-    initLogging ();
-
     qRegisterMetaType<ContactInfo>("ContactInfo");
 
     // Status from contacts object
@@ -46,67 +46,12 @@ MainWindow::MainWindow(QObject *parent /*= 0*/)
     QTimer::singleShot (100, this, SLOT(doWork ()));
 }//MainWindow::MainWindow
 
-void
-MainWindow::initLogging ()
-{
-    QString strLogfile = baseDir ();
-    strLogfile += QDir::separator();
-    strLogfile += "notify.log";
-    fLogfile.setFileName (strLogfile);
-    fLogfile.open (QIODevice::WriteOnly | QIODevice::Append);
-}//MainWindow::initLogging
-
-/** Log information to console and to log file
- * This function is invoked from the qDebug handler that is installed in main.
- * @param strText Text to be logged
- * @param level Log level
- */
-void
-MainWindow::log (const QString &strText, int level /*= 10*/)
-{
-    QString strDisp;
-    QRegExp regex("^\"(.*)\"\\s*");
-    if (strText.indexOf (regex) != -1) {
-        strDisp = regex.cap (1);
-    } else {
-        strDisp = strText;
-    }
-
-    QDateTime dt = QDateTime::currentDateTime ();
-    QString strLog = QString("%1 : %2 : %3")
-                     .arg(dt.toString ("yyyy-MM-dd hh:mm:ss.zzz"))
-                     .arg(level)
-                     .arg(strDisp);
-
-    // Send to standard output
-    cout << strLog.toStdString () << endl;
-
-    // Send to log file
-    if (fLogfile.isOpen ()) {
-        QTextStream streamLog(&fLogfile);
-        streamLog << strLog << endl;
-    }
-}//MainWindow::log
-
 void
 MainWindow::setStatus(const QString &strText, int /*timeout = 3000*/)
 {
     qDebug () << strText;
 }//MainWindow::setStatus
 
-QString
-MainWindow::baseDir()
-{
-    QString strBasedir = QDir::homePath();
-    QDir baseDir(strBasedir);
-    if (!baseDir.exists (".qgvdial")) {
-        baseDir.mkdir (".qgvdial");
-    }
-    strBasedir += QDir::separator();
-    strBasedir += ".qgvdial";
-    return strBasedir;
-}//MainWindow::baseDir
-
 void
 MainWindow::doWork ()
 {
