@@ -158,6 +158,7 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
               .arg (account->cmName ());
         Q_DEBUG (msg);
 
+#if 0
         // We can find out some information about this account
         QVariantMap varMap = account->parameters ();
         for (QVariantMap::iterator i = varMap.begin ();
@@ -168,6 +169,7 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
                   .arg (i.value().toString ());
             Q_DEBUG (msg);
         }
+#endif
     } while (0); // End cleanup block (not a loop)
 
     emit changed ();
@@ -349,6 +351,8 @@ TpCalloutInitiator::sendDTMF (const QString &strTones)
 
         Q_DEBUG("DTMF tones sent");
         rv = true;
+#else
+        Q_UNUSED(strTones);
 #endif
     } while (0); // End cleanup block (not a loop)
 
@@ -375,7 +379,6 @@ TpCalloutInitiator::onDtmfNextTone()
             break;
         }
 
-        Q_DEBUG("Here");
 #if !USE_RAW_CHANNEL_METHOD
         Tp::StreamedMediaStreams streams =
             channel->streamsForType(Tp::MediaStreamTypeAudio);
